QuCAT: Quantum Circuit Analyzer Tool in Python
==============================================

Maintained by [Mario Gely](https://github.com/mgely)

QuCAT stands for Quantum Circuit Analyzer Tool. This open source python library provides standard analysis tools for superconducting electronic circuits, built around Josephson junctions.

QuCAT features an intuitive graphical or programmatical interface to create circuits, the ability to compute their Hamiltonian, and a set of complimentary functionalities such as calculating dissipation rates or visualizing current flows in the circuit. QuCAT currently supports quantization in the basis of normal modes.

**If you find QuCAT useful, please consider citing it in your publications, see: https://qucat.org/citing.html.**

If you have questions concerning the usage or installation of QuCAT, please ask questions on [our forum](https://groups.google.com/forum/#!forum/qucat).

Installation
------------

[![Downloads](https://pepy.tech/badge/qucat)](https://pepy.tech/project/qucat)

The recommended way to install qucat is via pip by opening a terminal and running ``pip install qucat``, more information [here](https://qucat.org/installation.html).

Documentation
------------------

Visit https://qucat.org/ for all information about installation, a documented lists of functions, tutorials and more.

Tutorials
---------

A selection of tutorials is available [here](https://qucat.org/tutorials/tutorials.html).

Build status and test coverage
------------------------------

Master branch:
[![Build Status](https://github.com/qucat/qucat/actions/workflows/tests.yml/badge.svg?branch=master)](https://github.com/qucat/qucat/actions)
[![codecov](https://codecov.io/gh/qucat/qucat/branch/master/graph/badge.svg)](https://codecov.io/gh/qucat/qucat)

Contribute
----------

You are most welcome to contribute to QuCAT development by forking this
repository and sending pull requests.

Filing bug reports, proposing changes or additional features can be done on our
[issues page](https://github.com/qucat/qucat/issues/new/choose)

You can also contact Mario at mario.gely@qucat.org
 